<h1>lsbranch</h1>

[![PyPI version](https://badge.fury.io/py/lsbranch.svg)](https://badge.fury.io/py/lsbranch)

<p>List all directories with .git subdirectory and show current branch for each.</p>

<h3>Instalation</h3>

```
pip install lsbranch
```

<h3>Usage</h3>

<p>Just go to any directory with git projects subdirectories and type "lsbranch". You'll get the list of subdirectories with current branch next to each.</p>
